
//Licensed Materials - Property of IBM 
// Copyright IBM Corporation 2006, 2008. All Rights Reserved.

package com.telelogic.rhapsody.core;


/**
 * The IRPProject interface represents Rational Rhapsody projects.
 */
public interface IRPProject  extends IRPPackage {
	/**
 	 * For internal use only.
 	 */
	public void gatewayExportToXML(String filename, String params);
	/**
 	 * For internal use only.
 	 */
	public void gatewayExportToXML2(String filename, String params, IRPProject proj);
	/**
 	 * Generates a ReporterPLUS report for the model. (When this method is used to generate a report, the Rhapsody model is saved before the report is generated.)
 	 * <pre> 
 	 * // Sample code:
 	 * IRPProject currentProject = app.activeProject();
 	 * currentProject.generateReport("", "C:\Rhapsody\reporterplus\Templates\Class.tpl", "html", "C:\testreport.html", 0, 0);
 	 * </pre> 
 	 * @param modelscope the name of the package for which the report should be generated. If empty, a report is generated for the entire model. (This is similar to the "scope" command-line option for ReporterPLUS.)
 	 * @param templatename the name of the template to use. If empty, then the ReporterPLUS report generation wizard will be launched and it will display the name of the last template used.
 	 * @param docType the type of output to generate (doc, html, ppt, txt). If empty, the ReporterPLUS report generation wizard will be launched and it will display the last output type used.
 	 * @param filename the filename to use for the generated report. If empty, the ReporterPLUS report generation wizard will be displayed and it will display the filename of the last generated report.
 	 * @param showDocument In general, the user will be asked if they want to view the report after generation only if they have requested this by selecting View &gt; Options &gt; Ask to open after generating report from the main menu in ReporterPLUS. However, if the user has specified silent generation mode using the parameter silentMode, this parameter can be used to request that the generated document be displayed. To display the report, set this parameter to 1, otherwise use 0. 
 	 * @param silentMode If the template name, document type, or output file name has not been specified using the appropriate parameter, the ReporterPLUS report generation wizard is displayed so the user can provide the missing information. This is the behavior if this parameter is set to 0. If you want to prevent the wizard from being launched in such cases, you can specify silent generation mode by setting this parameter to 1. If set to silent mode, no report will be generated if one or more of the above parameters was not provided. (The report generation status dialog is displayed regardless of the value of this parameter.)
 	 */
	public void generateReport(String modelscope, String templatename, String docType, String filename, int showDocument, int silentMode);
	/**
 	 * Adds a new Component to the project.
 	 * @param name the name to use for the new Component
 	 * @return the Component that was created
 	 */
	public IRPComponent addComponent(String name);
	/**
 	 * Adds a new package to the project.
 	 * @param name the name to use for the new package
 	 * @return the package that was created
 	 */
	public IRPPackage addPackage(String name);
	/**
 	 * Adds a new profile to the project.
 	 * @param name the name to use for the new profile
 	 * @return the profile that was created
 	 */
	public IRPProfile addProfile(String name);
	/**
 	 * For internal use only.
 	 */
	public void addSpellCheckerResult(String value);
	/**
 	 * Can be used to temporarily disable autosaving of the model regardless of the current value of the property General::Model::AutoSaveInterval.
 	 * @param allow Use 0 to turn off autosave, use 1 to turn autosave on
 	 */
	public void allowAutoSave(int allow);
	/**
 	 * For internal use only.
 	 */
	public void allowNonUniqueNames(int allow);
	/**
 	 * For internal use only.
 	 */
	public void applyRoundtripDiffMerge(int magicNumber, IRPProject shadowModel, IRPCollection filesToUpdate);
	/**
 	 * Makes this project the active project in Rhapsody. For use when you have multiple projects open in Rhapsody.
 	 */
	public void becomeActiveProject();
	/**
	 * method checkEventsBaseIdsSolveCollisions 
	 * @throws RhapsodyRuntimeException
	 */
	public void checkEventsBaseIdsSolveCollisions();
	/**
 	 * Removes any unresolved elements from the model, starting at the level of the specified element and working downward.
 	 * @param rootElement the element below which Rhapsody should remove all unresolved elements
 	 */
	public void cleanUnresolvedElements(IRPModelElement rootElement);
	/**
 	 * Closes the project.
 	 */
	public void close();
	/**
 	 * Closes the tab in the Output window for the specified csv file.
 	 * @param fullCSVFileName the path of the csv file that should be closed
 	 */
	public void closeCSVFile(String fullCSVFileName);
	/**
 	 * Deletes the specified Component.
 	 * @param component the Component that should be deleted
 	 */
	public void deleteComponent(IRPComponent component);
	/**
	 * method endTransactionOfNoCGInterest
	 * @throws RhapsodyRuntimeException
	 */
	public void endTransactionOfNoCGInterest();
	/**
 	 * Returns the Component with the specified name.
 	 * @param name the name of the Component to return
 	 * @return the Component with the specified name
 	 */
	public IRPComponent findComponent(String name);
	/**
 	 * Retrieves a model element based on its binary ID. This operation can be used in conjunction with the operation IRPModelElement.getBinaryID, which returns the binary ID of the element. In some situations, findElementByBinaryID is faster than the operation IRPProject.findElementByGUID.
 	 * @param theID the binary ID for the model element that should be retrieved
 	 * @return the model element with the specified binary ID
 	 */
	public IRPModelElement findElementByBinaryID(byte[] theID);
	/**
 	 * Retrieves a model element based on its GUID.
 	 * @param theGUID the GUID for the model element that should be retrieved
 	 * @return the model element with the specified GUID
 	 */
	public IRPModelElement findElementByGUID(String theGUID);
	/**
 	 * Returns the active component.
 	 * @return the active component
 	 */
	public IRPComponent getActiveComponent();
	/**
 	 * Returns the active configuration.
 	 * @return the active configuration
 	 */
	public IRPConfiguration getActiveConfiguration();
	/**
 	 * Returns a collection of all the stereotypes in the project.
 	 * @return all the stereotypes in the project
 	 */
	public IRPCollection getAllStereotypes();
	/**
 	 * Returns the package that contains the simplified model.
 	 * @return the package that contains the simplified model
 	 */
	public IRPPackage getCgSimplifiedModelPackage();
	/**
	 * method getCodeGeneratedFiles
	 * @throws RhapsodyRuntimeException
	 */
	public IRPCollection getCodeGeneratedFiles();
	/**
 	 * Returns a collection of all the components in the project.
 	 * @return all the components in the project
 	 */
	public IRPCollection getComponents();
	/**
 	 * Returns the project's default directory scheme with regard to packages. "Flat" means that all new units are saved in a single directory. "PackageAsDirectory" means that a new directory is created for each package in the model. This setting is controlled by the property General::Model::DefaultDirectoryScheme.
 	 * @return the project's default directory scheme with regard to packages - Flat or PackageAsDirectory
 	 */
	public String getDefaultDirectoryScheme();
	/**
 	 * Creates a new IRPCollaboration object that can be used to create a sequence diagram.
 	 * @return the IRPCollaboration object that was created
 	 */
	public IRPCollaboration getNewCollaboration();
	/**
	 * method getNewProgressBar
	 * @throws RhapsodyRuntimeException
	 */
	public IRPProgressBar getNewProgressBar(int amount, String name);
	/**
 	 * Returns a collection of all the profiles in the project.
 	 * @return all the profiles in the project
 	 */
	public IRPCollection getProfiles();
	/**
	 * method getRequirementsByID
	 * @throws RhapsodyRuntimeException
	 */
	public IRPCollection getRequirementsByID(String requirementID, int returnFirstFoundOnly);
	/**
 	 * For internal use only.
 	 */
	public IRPProject getRoundtripShadowModel(int magicNumber);
	/**
	 * method highlightFromCode
	 * @throws RhapsodyRuntimeException
	 */
	public IRPModelElement highlightFromCode(String filename, int lineNumber);
	/**
 	 * Imports the specified Rose package.
 	 * @param projectName the Rose project from which the package should be imported (path that includes the name of the *.mdl file)
 	 * @param packageName the name of the Rose package to import
 	 * @param logFileName the file to use for logging the import process
 	 */
	public void importPackageFromRose(String projectName, String packageName, String logFileName);
	/**
 	 * Imports the specified Rose project.
 	 * @param projectName the Rose project to import (path that includes the name of the *.mdl file)
 	 * @param logFileName the file to use for logging the import process
 	 */
	public void importProjectFromRose(String projectName, String logFileName);
	/**
 	 * Checks whether any part of the project has been modified and the project needs to be saved.
 	 * @return 1 if any part of the project has been modified, 0 if no changes have been made
 	 */
	public int isModifiedRecursive();
	/**
	 * method locateInIDE
	 * @throws RhapsodyRuntimeException
	 */
	public void locateInIDE(IRPConfiguration config, String filename, int lineNumber);
	/**
 	 * Moves the model to a Rhapsody Design Manager server. Note that this operation is only intended for the initial move of a model to the DM server. It cannot be used to replace an existing model on the server.
 	 * @param userName the username for logging in to the Design Manager server
 	 * @param password the password for logging in to the Design Manager server
 	 * @param serverURL the URL of the Design Manager server
 	 * @param projectAreaName the name of the Project Area to use for this model
 	 * @param streamName the name of the Stream to use for this model
 	 */
	public void moveToDesignManager(String userName, String password, String serverURL, String projectAreaName, String streamName);
	/**
	 * moveToDesignManagerAfterLogin
	 * @throws RhapsodyRuntimeException
	 */
	public void moveToDesignManagerAfterLogin(String serverURL, String projectAreaName, String streamName);
	/**
 	 * Displays the content of the specified csv file in a new tab in the Output window.
 	 * @param fullCSVFileName the path of the csv file that should be displayed
 	 * @param reserved this parameter has no effect, you can use any integer
 	 */
	public void openCSVFile(String fullCSVFileName, int reserved);
	/**
 	 * If you are using Rational Rhapsody's default numbering scheme for event IDs, then a certain amount of IDs are reserved for each package. As a result, there are situations where the IDs used for events in a given package may not be continuous. In cases like this, you can use the method recalculateEventsBaseIds to have the event ID numbering recalculated so that event IDs are continuous for all events within each package in the project.
 	 */
	public void recalculateEventsBaseIds();
	/**
 	 * Reloads the content of the specified csv file in a tab in the Output window.
 	 * @param fullCSVFileName the path of the csv file that should be reloaded
 	 */
	public void reloadCSVFile(String fullCSVFileName);
	/**
	 * Remove project from current workspace
	 * @throws RhapsodyRuntimeException
	 */
	public int remove();
	/**
 	 * Saves the project.
 	 */
	public void save();
	/**
 	 * Saves the project using the specified path.
 	 * @param filename the path to use for saving the project
 	 */
	public void saveAs(String filename);
	/**
 	 * Saves the project, using the format of a previous version of Rhapsody.
 	 * @param filename the path to use for saving the project
 	 * @param prevVersion the Rhapsody version whose format you want to use for saving the project. The valid strings for this parameter are those that are used in the Save As dialog in the user interface, for example, "7.6.1".
 	 */
	public void saveAsPrevVersion(String filename, String prevVersion);
	/**
 	 * Sets the specified component as the active component for the project.
 	 * @param name the name of the component that should be set as the active component for the project. The string should represent the location of the component in the project hierarchy, using a double colon (::) as the delimiter, for example, Default::subpackage_1::component_a::subcomponent_b. If the component is not contained in a package or within another component, you can just use the name of the component.
 	 */
	public void setActiveComponent(String name);
	/**
 	 * Sets the specified component as the active component for the project.
 	 * @param name the name of the component that should be set as the active component for the project. The string should represent the location of the component in the project hierarchy, using a double colon (::) as the delimiter, for example, Default::subpackage_1::component_a::subcomponent_b. If the component is not contained in a package or within another component, you can just use the name of the component.
 	 */
	public void setActiveComponent(IRPComponent activeComponent);
	/**
 	 * Sets the configuration with the specified name to be the active configuration of the project.
 	 * @param name the name of the configuration to set as the active configuration. The configuration must belong to the active component.
 	 */
	public void setActiveConfiguration(String name);
	/**
 	 * Sets the configuration with the specified name to be the active configuration of the project.
 	 * @param name the name of the configuration to set as the active configuration. The configuration must belong to the active component.
 	 */
	public void setActiveConfiguration(IRPConfiguration activeConfiguration);
	/**
 	 * Set's the project's default directory scheme with regard to packages. This setting is controlled by the property General::Model::DefaultDirectoryScheme.
 	 * @param defaultDirectoryScheme the default directory scheme to use for packages in the model. The valid values for this parameter are: "Flat" - all new units are saved in a single directory, and "PackageAsDirectory" - a new directory is created for each package in the model.
 	 */
	public void setDefaultDirectoryScheme(String defaultDirectoryScheme);
	/**
 	 * Changes the specified object to an explicit object. As a result, a class is added to the model with the name [object name]_Class. This method corresponds to the Expose Class option in the pop-up menu of the Rhapsody model browser.
 	 * @param pInstance the object that should be changed to explicit
 	 */
	public void setObjectExplicit(IRPInstance pInstance);
	/**
 	 * Changes the specified object to an implicit object.
 	 * @param pInstance the object that should be changed to implicit
 	 */
	public void setObjectImplicit(IRPInstance pInstance);
	/**
	 * set property UseUniqueStereotypeAndRefCache
	 * @throws RhapsodyRuntimeException
	 */
	public void setUseUniqueStereotypeAndRefCache(int useUniqueStereotypeAndRefCache);
	/**
	 * method setWaitDialogWatchdogValue
	 * @throws RhapsodyRuntimeException
	 */
	public void setWaitDialogWatchdogValue(String value);
	/**
	 * method startTransactionOfNoCGInterest
	 * @throws RhapsodyRuntimeException
	 */
	public void startTransactionOfNoCGInterest();
}

